@@ -20,17 +20,10 @@
 
 set -e
 
+. ./config.status
 . ${srcdest}build-aux/config.sh
 . ${srcdest}build-aux/trace.sh
 
-export GUILE MES
-MES=${MES-./src/mes}
-
-GUILE=${GUILE-guile}
-if ! command -v $GUILE > /dev/null; then
-    GUILE=true
-fi
-
 tests="
 
 00-zero.scm
@@ -53,6 +46,13 @@ tests="
 
 16-if-eq-quote.scm
 
+17-memq.scm
+17-memq-keyword.scm
+17-string-equal.scm
+17-equal2.scm
+17-string-append.scm
+17-open-input-string.scm
+
 20-define.scm
 20-define-quoted.scm
 20-define-quote.scm
@@ -106,6 +106,8 @@ tests="
 4e-let-global.scm
 4f-string-split.scm
 
+50-string-append.scm
+50-string-join.scm
 50-primitive-load.scm
 51-module.scm
 52-define-module.scm
@@ -120,18 +122,17 @@ for i in $tests; do
         echo ' [SKIP]'
         continue;
     fi
-    trace "TEST       $i.guile" $GUILE -L ${srcdest}module -C module -L . <(echo '(use-modules (mes guile))'; cat scaffold/boot/$i)
     x=$(
-        if [ "$MES" = guile ]; then
-            true
+        if [ "$MES" = guile -o "$(basename $MES)" = guile ]; then
+            trace "TEST       $i.guile" $GUILE -L ${srcdest}module -C module -L . <(echo '(use-modules (mes guile))'; cat scaffold/boot/$i)
         elif [ -z "${i/5[0-9]-*/}" ]; then
-            cat scaffold/boot/$i | MES_BOOT=${srcdest}boot-00.scm $MES 2>&1;
+            cat scaffold/boot/$i | MES_BOOT=${srcdest}boot-00.scm trace "TEST       $i" $MES 2>&1;
         elif [ -z "${i/6[0-9]-*/}" ]; then
-            cat scaffold/boot/$i | MES_BOOT=${srcdest}boot-01.scm $MES 2>&1;
+            cat scaffold/boot/$i | MES_BOOT=${srcdest}boot-01.scm trace "TEST       $i" $MES 2>&1;
         else
-            MES_BOOT=${srcdest}scaffold/boot/$i $MES 2>&1;
+            MES_BOOT=${srcdest}scaffold/boot/$i trace "TEST       $i" $MES 2>&1;
         fi
      ) \
-        && echo ' [PASS]' \
+        && echo ' [OK]' \
         || (r=$?; echo ' [FAIL]'; echo -e "$x"; echo scaffold/boot/$i; exit $r)
 done
