@@ -44,11 +44,14 @@ int errno;
 #define	ECHILD  10
 #define EAGAIN  11
 #define ENOMEM  12
+#define EACCES  13
 #define EEXIST  17
 #define ENOTDIR 20
 #define EISDIR  21
 #define EINVAL  22
 #define EMFILE  24
+#define ENOSPC  28
+#define ESPIPE  29
 #define EPIPE   32
 #define ERANGE  34
 
