@@ -29,19 +29,12 @@
 
 #else // ! WITH_GLIBC
 
-#define CHAR_BIT 8
-#define UCHAR_MAX 255
-#define CHAR_MAX 255
-#define UINT_MAX 4294967295U
-#define ULONG_MAX 4294967295U
-#define INT_MIN -2147483648
-#define INT_MAX 2147483647
+#include <stdint.h>
+
 #define MB_CUR_MAX 1
-#define LONG_MIN -2147483648
-#define LONG_MAX 2147483647
-#define _POSIX_OPEN_MAX 16
-#define PATH_MAX 512
 #define NAME_MAX 255
+#define PATH_MAX 512
+#define _POSIX_OPEN_MAX 16
 
 #endif // ! WITH_GLIBC
 
