@@ -59,6 +59,7 @@
 #define SYS_pipe      0x16
 #define SYS_getgid    0x68
 #define SYS_rt_sigaction 0x0d
+#define SYS_rt_sigreturn 0x0f
 #define SYS_fcntl     0x48
 #define SYS_dup2      0x21
 #define SYS_getrusage 0x62
@@ -69,4 +70,14 @@
 #define SYS_getdents  0x4e
 #define SYS_clock_gettime 0xe4
 
+// bash
+#define SYS_setuid    0x69
+#define SYS_setgid    0x6a
+#define SYS_geteuid   0x6b
+#define SYS_getegid   0x6c
+#define SYS_getppid   0x6e
+
+// make+POSIX
+#define SYS_rt_sigprocmask 0x0e
+
 #endif // __MES_LINUX_X86_64_SYSCALL_H
