@@ -76,6 +76,7 @@ typedef long stack_t;
 #define SA_NOCLDSTOP 0x00000001
 #define SA_NOCLDWAIT 0x00000002
 #define SA_SIGINFO   0x00000004
+#define SA_RESTORER  0x04000000
 #define SA_ONSTACK   0x08000000
 #define SA_RESTART   0x10000000
 #define SA_NODEFER   0x40000000
@@ -228,6 +229,12 @@ void* signal (int signum, void * action);
 sighandler_t signal (int signum, sighandler_t action);
 #endif
 int sigemptyset (sigset_t *set);
+#ifndef SIG_BLOCK
+#define SIG_BLOCK 0
+#define SIG_UNBLOCK 1
+#define SIG_SETMASK 2
+#endif
+int sigprocmask (int how, sigset_t const *set, sigset_t *oldset);
 
 #endif //! WITH_GLIBC
 
