@@ -101,6 +101,17 @@ int stat (char const *file_name, struct stat *buf);
 #define S_IWUSR 00200
 #define S_IRUSR 00400
 
+#define S_ISUID 0400
+#define S_ISGID 02000
+#define S_IXGRP 00010
+#define S_IXOTH 00001
+#define S_IRGRP 00040
+#define S_IROTH 00004
+#define S_IWGRP 00020
+#define S_IWOTH 00002
+#define S_IRWXG 00070
+#define S_IRWXO 00007
+
 #endif // ! WITH_GLIBC
 
 #endif // __MES_SYS_STAT_H
