@@ -18,4 +18,4 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <getopt.c>
+#include <posix/getopt.c>
