@@ -37,12 +37,6 @@ lseek (int filedes, off_t offset, int whence)
   return _sys_call3 (SYS_lseek, (int)filedes, (long)offset, (int)whence);
 }
 
-int
-unlink (char const *file_name)
-{
-  return _sys_call1 (SYS_unlink, (long)file_name);
-}
-
 int
 rmdir (char const *file_name)
 {
@@ -54,21 +48,3 @@ stat (char const *file_name, struct stat *statbuf)
 {
   return _sys_call2 (SYS_stat, (long)file_name, (long)statbuf);
 }
-
-char *
-getcwd (char *buffer, size_t size)
-{
-  return _sys_call2 (SYS_getcwd, (long)buffer, (long)size);
-}
-
-time_t
-time (time_t *result)
-{
-  return _sys_call1 (SYS_time, (long)result);
-}
-
-int
-gettimeofday (struct timeval *tv, struct timezone *tz)
-{
-  return _sys_call2 (SYS_gettimeofday, (long)tv, (long)tz);
-}
