@@ -19,57 +19,31 @@
  */
 
 #include <setjmp.h>
-#include <stdarg.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <time.h>
-#include <signal.h>
-#include <sys/mman.h>
-#include <sys/time.h>
-#include <unistd.h>
-
-int errno;
 
 void
 longjmp (jmp_buf env, int val)
 {
   val = val == 0 ? 1 : val;
-  asm ("mov    %esi,%eax\n\t"           // val
-
+  asm (
        "mov    0x00(%rdi),%rbp\n\t"     // env->__bp
        "mov    0x08(%rdi),%rbx\n\t"     // env->__pc
-       "mov    0x16(%rdi),%rsp\n\t"     // env->__sp
+       "mov    0x10(%rdi),%rsp\n\t"     // env->__sp
        "jmp    *%rbx\n\t"               // jmp *PC
        );
   // not reached
   exit (42);
 }
 
-#if 0
-int
-setjmp_debug (jmp_buf env, int val)
-{
-  int i;
-#if 1
-  i = env->__bp;
-  i = env->__pc;
-  i = env->__sp;
-#else
-  i = env[0].__bp;
-  i = env[0].__pc;
-  i = env[0].__sp;
-#endif
-  return val == 0 ? 1 : val;
-}
-#endif
-
 int
 setjmp (jmp_buf env)
 {
-  int *p = (int*)&env;
-  env[0].__bp = p[-2];
-  env[0].__pc = p[-1];
-  env[0].__sp = (long)&env;
+  long *p;
+  asm ("mov    %%rbp,%0"
+       : "=r" (p)
+       : //no inputs ""
+       );
+  env[0].__bp = p;
+  env[0].__pc = p[1];
+  env[0].__sp = p[0];
   return 0;
 }
