@@ -20,7 +20,7 @@
 (define mes %version)
 
 (define (defined? x)
-  (assq x (current-module)))
+  (module-variable (current-module) x))
 
 (define (cond-expand-expander clauses)
   (if (defined? (car (car clauses)))
@@ -36,7 +36,6 @@
 (define <cell:pair> 7)
 (define <cell:string> 10)
 
-(define (pair? x) (eq? (core:type x) <cell:pair>))
 (define (not x) (if x #f #t))
 
 (define (display x . rest)
@@ -47,9 +46,6 @@
   (if (null? rest) (core:write x)
       (core:write-port x (car rest))))
 
-(define (list->string lst)
-  (core:make-cell <cell:string> lst 0))
-
 (define (integer->char x)
   (core:make-cell <cell:character> 0 x))
 
@@ -139,35 +135,17 @@
       (if (eq? x (car lst)) lst
           (memq x (cdr lst)))))
 
-;; (cond-expand
-;;  (guile
-;;   (define closure identity)
-;;   (define body identity)
-;;   (define append2 append)
-;;   (define (core:apply f a m) (f a))
-;;   )
-;;  (mes
   (define <cell:symbol> 11)
   (define (symbol? x)
     (eq? (core:type x) <cell:symbol>))
 
-  (define (string->symbol s)
-    (if (not (pair? (core:car s))) '()
-        (core:lookup-symbol (core:car s))))
-
   (define <cell:string> 10)
   (define (string? x)
     (eq? (core:type x) <cell:string>))
-  
+
   (define <cell:vector> 14)
   (define (vector? x)
     (eq? (core:type x) <cell:vector>))
- 
-  ;; (define (body x)
-  ;; (core:cdr (core:cdr (core:cdr (cdr (assq 'x (current-module)))))))
-  ;; (define (closure x)
-  ;;   (map car (cdr (core:cdr (core:car (core:cdr (cdr (assq 'x (current-module)))))))))
-  ;; ))
 
 (define (cons* . rest)
   (if (null? (cdr rest)) (car rest)
@@ -183,9 +161,7 @@
           (append2 (car rest) (apply append (cdr rest))))))
 
 (define-macro (quasiquote x)
-  ;;(core:display-error "quasiquote:") (core:write-error x) (core:display-error "\n")
   (define (loop x)
-    ;;(core:display-error "loop:") (core:write-error x) (core:display-error "\n")
     (if (vector? x) (list 'list->vector (loop (vector->list x)))
         (if (not (pair? x)) (cons 'quote (cons x '()))
             (if (eq? (car x) 'quasiquote) (loop (loop (cadr x)))
@@ -249,7 +225,7 @@
           (and (equal2? (car a) (car b))
                (equal2? (cdr a) (cdr b)))
           (if (and (string? a) (string? b))
-              (eq? (string->symbol a) (string->symbol b))
+              (string=? a b)
               (if (and (vector? a) (vector? b))
                   (equal2? (vector->list a) (vector->list b))
                   (eq? a b))))))
@@ -362,14 +338,14 @@
         (and (segment-template? pattern)
              (or (null? (cddr pattern))
                  (syntax-error0 "segment matching not implemented" pattern))))
-    
+
       (define (segment-template? pattern)
         (and (pair? pattern)
              (pair? (cdr pattern))
              (memq (cadr pattern) indicators-for-zero-or-more)))
-    
+
       (define indicators-for-zero-or-more (list (string->symbol "...") '---))
-    
+
       (lambda (exp r c)
 
         (define %input (r '%input))     ;Gensym these, if you like.
@@ -406,7 +382,7 @@
                                        0
                                        (meta-variables pattern 0 '())))))
               (syntax-error2 "ill-formed syntax rule" rule)))
-      
+
         ;; Generate code to test whether input expression matches pattern
 
         (define (process-match input pattern)
@@ -427,7 +403,7 @@
                  `((eq? ,input ',pattern)))
                 (else
                  `((equal? ,input ',pattern)))))
-      
+
         (define (process-segment-match input pattern)
           ;;(core:display-error "process-segment-match:") (core:write-error input) (core:display-error "\n")
           ;;(core:display-error "              pattern:") (core:write-error pattern) (core:display-error "\n")
@@ -439,7 +415,7 @@
                         (and (pair? l)
                              ,@conjuncts
                              (loop (cdr l)))))))))
-      
+
         ;; Generate code to take apart the input expression
         ;; This is pretty bad, but it seems to work (can't say why).
 
@@ -560,5 +536,3 @@
                         (if (not condition)
                             (begin exp ...))))))
    (xwhen #f 42)))
-
-
