@@ -34,6 +34,7 @@
 
 int ARENA_SIZE = 200000; // 32b: 2MiB, 64b: 4 MiB
 int MAX_ARENA_SIZE = 300000000;
+long STACK_SIZE = 20000;
 int JAM_SIZE = 20000;
 int GC_SAFETY = 2000;
 
@@ -48,6 +49,9 @@ SCM g_symbols = 0;
 SCM g_macros = 0;
 SCM g_ports = 0;
 SCM g_stack = 0;
+SCM *g_stack_array = 0;
+#define FRAME_SIZE 5
+#define FRAME_PROCEDURE 4
 // a/env
 SCM r0 = 0;
 // param 1
@@ -56,8 +60,10 @@ SCM r1 = 0;
 SCM r2 = 0;
 // continuation
 SCM r3 = 0;
+// current-module
+SCM m0 = 0;
 
-enum type_t {TCHAR, TCLOSURE, TCONTINUATION, TFUNCTION, TKEYWORD, TMACRO, TNUMBER, TPAIR, TPORT, TREF, TSPECIAL, TSTRING, TSYMBOL, TVALUES, TVARIABLE, TVECTOR, TBROKEN_HEART};
+enum type_t {TCHAR, TCLOSURE, TCONTINUATION, TFUNCTION, TKEYWORD, TMACRO, TNUMBER, TPAIR, TPORT, TREF, TSPECIAL, TSTRING, TSTRUCT, TSYMBOL, TVALUES, TVARIABLE, TVECTOR, TBROKEN_HEART};
 
 struct scm {
   enum type_t type;
@@ -117,6 +123,7 @@ struct scm scm_symbol_sc_expander_alist = {TSYMBOL, "*sc-expander-alist*",0};
 struct scm scm_symbol_call_with_values = {TSYMBOL, "call-with-values",0};
 struct scm scm_call_with_current_continuation = {TSPECIAL, "*call/cc*",0};
 struct scm scm_symbol_call_with_current_continuation = {TSYMBOL, "call-with-current-continuation",0};
+struct scm scm_symbol_boot_module = {TSYMBOL, "boot-module",0};
 struct scm scm_symbol_current_module = {TSYMBOL, "current-module",0};
 struct scm scm_symbol_primitive_load = {TSYMBOL, "primitive-load",0};
 struct scm scm_symbol_read_input_file = {TSYMBOL, "read-input-file",0};
@@ -131,6 +138,15 @@ struct scm scm_symbol_wrong_number_of_args = {TSYMBOL, "wrong-number-of-args",0}
 struct scm scm_symbol_wrong_type_arg = {TSYMBOL, "wrong-type-arg",0};
 struct scm scm_symbol_unbound_variable = {TSYMBOL, "unbound-variable",0};
 
+struct scm scm_symbol_hashq_table = {TSYMBOL, "<hashq-table>",0};
+struct scm scm_symbol_record_type = {TSYMBOL, "<record-type>",0};
+struct scm scm_symbol_frame = {TSYMBOL, "<frame>",0};
+struct scm scm_symbol_module = {TSYMBOL, "<module>",0};
+struct scm scm_symbol_stack = {TSYMBOL, "<stack>",0};
+struct scm scm_symbol_buckets = {TSYMBOL, "buckets",0};
+struct scm scm_symbol_procedure = {TSYMBOL, "procedure",0};
+struct scm scm_symbol_size = {TSYMBOL, "size",0};
+
 struct scm scm_symbol_argv = {TSYMBOL, "%argv",0};
 struct scm scm_symbol_mes_prefix = {TSYMBOL, "%prefix",0};
 struct scm scm_symbol_mes_version = {TSYMBOL, "%version",0};
@@ -189,18 +205,20 @@ struct scm scm_type_port = {TSYMBOL, "<cell:port>",0};
 struct scm scm_type_ref = {TSYMBOL, "<cell:ref>",0};
 struct scm scm_type_special = {TSYMBOL, "<cell:special>",0};
 struct scm scm_type_string = {TSYMBOL, "<cell:string>",0};
+struct scm scm_type_struct = {TSYMBOL, "<cell:struct>",0};
 struct scm scm_type_symbol = {TSYMBOL, "<cell:symbol>",0};
 struct scm scm_type_values = {TSYMBOL, "<cell:values>",0};
 struct scm scm_type_variable = {TSYMBOL, "<cell:variable>",0};
 struct scm scm_type_vector = {TSYMBOL, "<cell:vector>",0};
 struct scm scm_type_broken_heart = {TSYMBOL, "<cell:broken-heart>",0};
 
+struct scm scm_symbol_internal_time_units_per_second = {TSYMBOL, "internal-time-units-per-second",0};
 struct scm scm_symbol_compiler = {TSYMBOL, "%compiler",0};
 struct scm scm_symbol_arch = {TSYMBOL, "%arch",0};
 
 struct scm scm_test = {TSYMBOL, "test",0};
 
-#include "mes.mes.symbols.h"
+#include "src/mes.mes.symbols.h"
 
 SCM tmp;
 SCM tmp_num;
@@ -209,19 +227,19 @@ SCM tmp_num2;
 struct function g_functions[200];
 int g_function = 0;
 
-#include "gc.mes.h"
-#include "lib.mes.h"
+#include "src/gc.mes.h"
+#include "src/lib.mes.h"
 #if !MES_MINI
-#include "math.mes.h"
+#include "src/math.mes.h"
 #endif
-#include "mes.mes.h"
+#include "src/mes.mes.h"
 
 SCM gc_init_news ();
 
 // #if !MES_MINI
-// #include "posix.mes.h"
+// #include "src/posix.mes.h"
 // #ndif
-//#include "vector.mes.h"
+//#include "src/vector.mes.h"
 
 #define TYPE(x) g_cells[x].type
 #define CAR(x) g_cells[x].car
@@ -234,6 +252,7 @@ SCM gc_init_news ();
 #define LENGTH(x) g_cells[x].car
 #define REF(x) g_cells[x].car
 #define STRING(x) g_cells[x].car
+#define STRUCT(x) g_cells[x].cdr
 #define VARIABLE(x) g_cells[x].car
 
 #define CLOSURE(x) g_cells[x].cdr
@@ -254,7 +273,7 @@ SCM gc_init_news ();
 #define MAKE_CONTINUATION(n) make_cell_ (tmp_num_ (TCONTINUATION), n, g_stack)
 #define MAKE_NUMBER(n) make_cell_ (tmp_num_ (TNUMBER), 0, tmp_num2_ (n))
 #define MAKE_REF(n) make_cell_ (tmp_num_ (TREF), n, 0)
-#define MAKE_STRING(x) make_cell_ (tmp_num_ (TSTRING), x, 0)
+#define MAKE_STRING0(x) make_string (x, strlen (x))
 
 #define CAAR(x) CAR (CAR (x))
 #define CADR(x) CAR (CDR (x))
@@ -330,15 +349,15 @@ list_of_char_equal_p (SCM a, SCM b) ///((internal))
 }
 
 SCM
-lookup_symbol_ (SCM s)
+list_to_symbol (SCM lst)
 {
   SCM x = g_symbols;
   while (x) {
-    if (list_of_char_equal_p (STRING (CAR (x)), s) == cell_t) break;
+    if (list_of_char_equal_p (STRING (CAR (x)), lst) == cell_t) break;
     x = CDR (x);
   }
   if (x) x = CAR (x);
-  if (!x) x = make_symbol_ (s);
+  if (!x) x = make_symbol_ (lst);
   return x;
 }
 
@@ -451,6 +470,14 @@ length (SCM x)
 
 SCM apply (SCM, SCM, SCM);
 
+SCM
+assq_ref_env (SCM x, SCM a)
+{
+  x = assq (x, a);
+  if (x == cell_f) return cell_undefined;
+  return CDR (x);
+}
+
 SCM
 error (SCM key, SCM x)
 {
@@ -627,18 +654,27 @@ call (SCM fn, SCM x)
 SCM
 assq (SCM x, SCM a)
 {
-  //FIXME: move into fast-non eq_p-ing assq core:assq?
-  //while (a != cell_nil && x != CAAR (a)) a = CDR (a);
-  while (a != cell_nil && eq_p (x, CAAR (a)) == cell_f) a = CDR (a);
+  while (a != cell_nil && eq_p (x, CAAR (a)) == cell_f)
+    a = CDR (a);
   return a != cell_nil ? CAR (a) : cell_f;
 }
 
 SCM
-assq_ref_env (SCM x, SCM a)
+assoc_string (SCM x, SCM a) ///(internal))
 {
-  x = assq (x, a);
-  if (x == cell_f) return cell_undefined;
-  return CDR (x);
+  while (a != cell_nil && list_of_char_equal_p (STRING (x), STRING (CAAR (a))) == cell_f)
+    a = CDR (a);
+  return a != cell_nil ? CAR (a) : cell_f;
+}
+
+SCM
+assoc (SCM x, SCM a)
+{
+  if (TYPE (x) == TSTRING)
+    return assoc_string (x, a);
+  while (a != cell_nil && equal2_p (x, CAAR (a)) == cell_f)
+    a = CDR (a);
+  return a != cell_nil ? CAR (a) : cell_f;
 }
 
 SCM
@@ -681,11 +717,8 @@ make_closure_ (SCM args, SCM body, SCM a) ///((internal))
 }
 
 SCM
-lookup_macro_ (SCM x, SCM a) ///((internal))
+macro_get_handle (SCM name)
 {
-  if (TYPE (x) != TSYMBOL) return cell_f;
-  SCM m = assq_ref_env (x, a);
-  if (TYPE (m) == TMACRO) return MACRO (m);
   return cell_f;
 }
 
@@ -776,10 +809,24 @@ make_tmps (struct scm* cells)
 }
 
 #if !MES_MINI
-#include "posix.c"
-#include "math.c"
+#include "src/posix.c"
+#include "src/math.c"
 #endif
-#include "lib.c"
+#include "src/lib.c"
+#include "src/strings.c"
+
+SCM frame_printer (SCM frame)
+{
+}
+SCM make_stack (SCM stack)
+{
+}
+SCM stack_length (SCM stack)
+{
+}
+SCM stack_ref (SCM stack, SCM index)
+{
+}
 
 // Jam Collector
 SCM g_symbol_max;
@@ -815,7 +862,7 @@ mes_symbols () ///((internal))
   gc_init_cells ();
   gc_init_news ();
 
-#include "mes.mes.symbols.i"
+#include "src/mes.mes.symbols.i"
 
   g_symbol_max = g_free;
   make_tmps (g_cells);
@@ -826,7 +873,7 @@ mes_symbols () ///((internal))
 
   SCM a = cell_nil;
 
-#include "mes.mes.symbol-names.i"
+#include "src/mes.mes.symbol-names.i"
 
   a = acons (cell_symbol_mes_version, MAKE_STRING (cstring_to_list (VERSION)), a);
   a = acons (cell_symbol_mes_prefix, MAKE_STRING (cstring_to_list (PREFIX)), a);
@@ -867,33 +914,35 @@ mes_environment () ///((internal))
 SCM
 mes_builtins (SCM a) ///((internal))
 {
-#include "mes.mes.i"
+#include "src/mes.mes.i"
 
 // Do not sort: Order of these includes define builtins
 #if !MES_MINI
-#include "posix.mes.i"
-#include "math.mes.i"
+#include "src/posix.mes.i"
+#include "src/math.mes.i"
 #endif
-#include "lib.mes.i"
+#include "src/lib.mes.i"
 #if !MES_MINI
-#include "vector.mes.i"
+#include "src/vector.mes.i"
 #endif
-#include "gc.mes.i"
+#include "src/gc.mes.i"
 #if !MES_MINI
-  //#include "reader.mes.i"
+  //#include "src/reader.mes.i"
 #endif
+#include "src/strings.mes.i"
 
-#include "gc.mes.environment.i"
-#include "lib.mes.environment.i"
+#include "src/gc.mes.environment.i"
+#include "src/lib.mes.environment.i"
 #if !MES_MINI
-#include "math.mes.environment.i"
+#include "src/math.mes.environment.i"
 #endif
-#include "mes.mes.environment.i"
+#include "src/mes.mes.environment.i"
 #if !MES_MINI
-#include "posix.mes.environment.i"
-  //#include "reader.mes.environment.i"
-#include "vector.mes.environment.i"
+#include "src/posix.mes.environment.i"
+  //#include "src/reader.mes.environment.i"
+#include "src/vector.mes.environment.i"
 #endif
+#include "src/strings.mes.i"
 
   return a;
 }
@@ -966,9 +1015,9 @@ bload_env (SCM a) ///((internal))
 }
 
 #if !MES_MINI
-#include "vector.c"
+#include "src/vector.c"
 #endif
-#include "gc.c"
+#include "src/gc.c"
 
 int
 main (int argc, char *argv[])
