@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2017 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2017,2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -27,26 +27,32 @@ main ()
   int t = 1;
   int one = t;
 
-  puts ("\n");
-  puts ("t: if (1 && 0)\n");
-  if (1 && 0) return 1;
+  oputs ("\n");
+  oputs ("t: if (1 && 0)\n");
+  if (1 && 0)
+    return 1;
 
-  puts ("t: if (!t && f)\n");
-  if (!t && f) return 1;
+  oputs ("t: if (!t && f)\n");
+  if (!t && f)
+    return 1;
 
-  puts ("t: if (t && !one)\n");
-  if (t && !one) return 1;
+  oputs ("t: if (t && !one)\n");
+  if (t && !one)
+    return 1;
 
-  puts ("t: if (f || !t)\n");
-  if (f || !t) return 1;
+  oputs ("t: if (f || !t)\n");
+  if (f || !t)
+    return 1;
 
-  puts ("t: if (1 && !0)\n");
-  if (1 && !0) goto ok0;
-  return 1;
+  oputs ("t: if (1 && !0)\n");
+  if (1 && !0)
+    goto ok0;
+    return 1;
  ok0:
 
-  puts ("t: if (f || t)\n");
-  if (f || t) goto ok1;
+  oputs ("t: if (f || t)\n");
+  if (f || t)
+    goto ok1;
   return 1;
  ok1:
 
