@@ -19,8 +19,7 @@
  */
 
 #include <libmes.h>
-#include <assert.h>
-#include <stdio.h>
+
 #include <string.h>
 
 int
