@@ -20,9 +20,12 @@
 
 #include <errno.h>
 
+size_t bytes_cells (size_t length);
+
 SCM
 gc_up_arena () ///((internal))
 {
+  long old_arena_bytes = (ARENA_SIZE+JAM_SIZE)*sizeof (struct scm);
   if (ARENA_SIZE >> 1 < MAX_ARENA_SIZE >> 2)
     {
       ARENA_SIZE <<= 1;
@@ -31,7 +34,8 @@ gc_up_arena () ///((internal))
     }
   else
     ARENA_SIZE = MAX_ARENA_SIZE -JAM_SIZE;
-  void *p = realloc (g_cells-1, (ARENA_SIZE+JAM_SIZE)*sizeof (struct scm));
+  long arena_bytes = (ARENA_SIZE+JAM_SIZE)*sizeof (struct scm);
+  void *p = realloc (g_cells-1, arena_bytes+STACK_SIZE*sizeof (SCM));
   if (!p)
     {
       eputs ("realloc failed, g_free=");
@@ -43,12 +47,13 @@ gc_up_arena () ///((internal))
       exit (1);
     }
   g_cells = (struct scm*)p;
+  memcpy (p + arena_bytes, p + old_arena_bytes, STACK_SIZE*sizeof (SCM));
   g_cells++;
 
   return 0;
 }
 
-SCM
+void
 gc_flip () ///((internal))
 {
   if (g_debug > 2)
@@ -60,7 +65,6 @@ gc_flip () ///((internal))
   if (g_free > JAM_SIZE)
     JAM_SIZE = g_free + g_free / 2;
   memcpy (g_cells-1, g_news-1, (g_free+2)*sizeof (struct scm));
-  return g_stack;
 }
 
 SCM
@@ -70,12 +74,29 @@ gc_copy (SCM old) ///((internal))
     return g_cells[old].car;
   SCM new = g_free++;
   g_news[new] = g_cells[old];
-  if (NTYPE (new) == TVECTOR)
+  if (NTYPE (new) == TSTRUCT
+      || NTYPE (new) == TVECTOR)
     {
       NVECTOR (new) = g_free;
       for (long i=0; i<LENGTH (old); i++)
         g_news[g_free++] = g_cells[VECTOR (old)+i];
     }
+  else if (NTYPE (new) == TBYTES)
+    {
+      char const *src = CBYTES (old);
+      char *dest = NCBYTES (new);
+      size_t length = NLENGTH (new);
+      memcpy (dest, src, length + 1);
+      g_free += bytes_cells (length) - 1;
+
+      if (g_debug > 4)
+        {
+          eputs ("gc copy bytes: "); eputs (src); eputs ("\n");
+          eputs ("    length: "); eputs (itoa (LENGTH (old))); eputs ("\n");
+          eputs ("    nlength: "); eputs (itoa (NLENGTH (new))); eputs ("\n");
+          eputs ("        ==> "); eputs (dest); eputs ("\n");
+        }
+    }
   TYPE (old) = TBROKEN_HEART;
   CAR (old) = new;
   return new;
@@ -95,7 +116,7 @@ gc_relocate_cdr (SCM new, SCM cdr) ///((internal))
   return cell_unspecified;
 }
 
-SCM
+void
 gc_loop (SCM scan) ///((internal))
 {
   SCM car;
@@ -104,16 +125,10 @@ gc_loop (SCM scan) ///((internal))
     {
       if (NTYPE (scan) == TBROKEN_HEART)
         error (cell_symbol_system_error,  cell_gc);
-      if (NTYPE (scan) == TFUNCTION
-          || NTYPE (scan) == TKEYWORD
-          || NTYPE (scan) == TMACRO
+      if (NTYPE (scan) == TMACRO
           || NTYPE (scan) == TPAIR
-          || NTYPE (scan) == TPORT
           || NTYPE (scan) == TREF
           || scan == 1 // null
-          || NTYPE (scan) == TSPECIAL
-          || NTYPE (scan) == TSTRING
-          || NTYPE (scan) == TSYMBOL
           || NTYPE (scan) == TVARIABLE)
         {
           car = gc_copy (g_news[scan].car);
@@ -121,17 +136,26 @@ gc_loop (SCM scan) ///((internal))
         }
       if ((NTYPE (scan) == TCLOSURE
            || NTYPE (scan) == TCONTINUATION
+           || NTYPE (scan) == TFUNCTION
+           || NTYPE (scan) == TKEYWORD
            || NTYPE (scan) == TMACRO
            || NTYPE (scan) == TPAIR
+           || NTYPE (scan) == TPORT
+           || NTYPE (scan) == TSPECIAL
+           || NTYPE (scan) == TSTRING
+           || NTYPE (scan) == TSYMBOL
+           || scan == 1 // null
            || NTYPE (scan) == TVALUES)
           && g_news[scan].cdr) // allow for 0 terminated list of symbols
         {
           cdr = gc_copy (g_news[scan].cdr);
           gc_relocate_cdr (scan, cdr);
         }
+      if (NTYPE (scan) == TBYTES)
+        scan += bytes_cells (NLENGTH (scan)) - 1;
       scan++;
     }
-  return gc_flip ();
+  gc_flip ();
 }
 
 SCM
@@ -199,14 +223,9 @@ gc_ () ///((internal))
   g_symbols = gc_copy (g_symbols);
   g_macros = gc_copy (g_macros);
   g_ports = gc_copy (g_ports);
-  SCM new = gc_copy (g_stack);
-  if (g_debug > 3)
-    {
-      eputs ("new=");
-      eputs (itoa (new));
-      eputs ("\n");
-    }
-  g_stack = new;
+  m0 = gc_copy (m0);
+  for (long i=g_stack; i<STACK_SIZE; i++)
+    g_stack_array[i]= gc_copy (g_stack_array[i]);
   gc_loop (1);
 }
 
