@@ -36,26 +36,36 @@ display_helper (SCM x, int cont, char* sep, int fd, int write_p)
         fdputc (VALUE (x), fd);
       else
         {
-          fdputs ("#\\", fd);
+          fdputs ("#", fd);
           long v = VALUE (x);
-          if (v == '\0') fdputs ("nul", fd);
-          else if (v == '\a') fdputs ("alarm", fd);
-          else if (v == '\b') fdputs ("backspace", fd);
-          else if (v == '\t') fdputs ("tab", fd);
-          else if (v == '\n') fdputs ("newline", fd);
-          else if (v == '\v') fdputs ("vtab", fd);
-          else if (v == '\f') fdputs ("page", fd);
+          if (v == '\0') fdputs ("\\nul", fd);
+          else if (v == '\a') fdputs ("\\alarm", fd);
+          else if (v == '\b') fdputs ("\\backspace", fd);
+          else if (v == '\t') fdputs ("\\tab", fd);
+          else if (v == '\n') fdputs ("\\newline", fd);
+          else if (v == '\v') fdputs ("\\vtab", fd);
+          else if (v == '\f') fdputs ("\\page", fd);
           //Nyacc bug
           // else if (v == '\r') fdputs ("return", fd);
-            else if (v == 13) fdputs ("return", fd);
-          else if (v == ' ') fdputs ("space", fd);
-          else fdputc (VALUE (x), fd);
+          else if (v == 13) fdputs ("\\return", fd);
+          else if (v == ' ') fdputs ("\\space", fd);
+          else
+            {
+              if (v >= 32 && v <= 127)
+                fdputc ('\\', fd);
+              fdputc (VALUE (x), fd);
+            }
         }
     }
   else if (t == TCLOSURE)
     {
       fdputs ("#<closure ", fd);
-      display_helper (CDR (x), cont, "", fd, 0);
+      SCM circ = CADR (x);
+      SCM name = CADR (circ);
+      SCM args = CAR (CDDR (x));
+      display_helper (CAR (name), 0, "", fd, 0);
+      fdputc (' ', fd);
+      display_helper (args, 0, "", fd, 0);
       fdputs (">", fd);
     }
   else if (t == TFUNCTION)
@@ -126,20 +136,27 @@ display_helper (SCM x, int cont, char* sep, int fd, int write_p)
            || t == TSTRING
            || t == TSYMBOL)
     {
-      if (TYPE (x) == TPORT)
+      if (t == TPORT)
         {
           fdputs ("#<port ", fd);
           fdputs (itoa (PORT (x)), fd);
           fdputs (" " ,fd);
+          x = STRING (x);
         }
-      if (TYPE (x) == TKEYWORD)
+      if (t == TKEYWORD)
         fdputs ("#:", fd);
-      if ((write_p && TYPE (x) == TSTRING) || TYPE (x) == TPORT)
+      if ((write_p && t == TSTRING) || t == TPORT)
         fdputc ('"', fd);
-      SCM t = CAR (x);
-      while (t && t != cell_nil)
+      char const *s = CSTRING (x);
+#if 0
+      s += START (x);
+      size_t length = LEN (x);
+#else
+      size_t length = LENGTH (x);
+#endif
+      for (size_t i=0; i < length; i++)
         {
-          long v = write_p ? VALUE (CAR (t)) : -1;
+          long v = write_p ? s[i] : -1;
           if (v == '\0') fdputs ("\\0", fd);
           else if (v == '\a') fdputs ("\\a", fd);
           else if (v == '\b') fdputs ("\\b", fd);
@@ -158,19 +175,42 @@ display_helper (SCM x, int cont, char* sep, int fd, int write_p)
 #endif
           else if (v == '\\') fdputs ("\\\\", fd);
           else if (v == '"') fdputs ("\\\"", fd);
-          else fdputc (VALUE (CAR (t)), fd);
-          t = CDR (t);
+          else fdputc (s[i], fd);
         }
-      if ((write_p && TYPE (x) == TSTRING) || TYPE (x) == TPORT)
+      if ((write_p && t == TSTRING) || t == TPORT)
         fdputc ('"', fd);
-      if (TYPE (x) == TPORT)
+      if (t == TPORT)
         fdputs (">", fd);
     }
+  else if (t == TREF)
+    fdisplay_ (REF (x), fd, write_p);
+  else if (t == TSTRUCT)
+    {
+      SCM printer = STRUCT (x) + 1;
+      if (TYPE (printer) == TREF)
+        printer = REF (printer);
+      if (TYPE (printer) == TCLOSURE
+          || TYPE (printer) == TFUNCTION)
+        apply (printer, cons (x, cell_nil), r0);
+      else
+        {
+          fdputs ("#<", fd);
+          fdisplay_ (STRUCT (x), fd, write_p);
+          SCM t = CAR (x);
+          long size = LENGTH (x);
+          for (long i=2; i<size; i++)
+            {
+              fdputc (' ', fd);
+              fdisplay_ (STRUCT (x) + i, fd, write_p);
+            }
+          fdputc ('>', fd);
+        }
+    }
   else if (t == TVECTOR)
     {
       fdputs ("#(", fd);
       SCM t = CAR (x);
-      for (long i = 0; i < LENGTH (x); i++)
+      for (long i = 0; i<LENGTH (x); i++)
         {
           if (i)
             fdputc (' ', fd);
@@ -181,7 +221,7 @@ display_helper (SCM x, int cont, char* sep, int fd, int write_p)
   else
     {
       fdputs ("<", fd);
-      fdputs (itoa (TYPE (x)), fd);
+      fdputs (itoa (t), fd);
       fdputs (":", fd);
       fdputs (itoa (x), fd);
       fdputs (">", fd);
@@ -189,6 +229,16 @@ display_helper (SCM x, int cont, char* sep, int fd, int write_p)
   return 0;
 }
 
+SCM
+procedure_name_ (SCM x)
+{
+  assert (TYPE (x) == TFUNCTION);
+  char const *p = "?";
+  if (FUNCTION (x).name != 0)
+    p = FUNCTION (x).name;
+  return MAKE_STRING0 (p);
+}
+
 SCM
 display_ (SCM x)
 {
@@ -200,7 +250,7 @@ SCM
 display_error_ (SCM x)
 {
   g_depth = 5;
-  return display_helper (x, 0, "", STDERR, 0);
+  return display_helper (x, 0, "", g_stderr, 0);
 }
 
 SCM
@@ -221,7 +271,7 @@ SCM
 write_error_ (SCM x)
 {
   g_depth = 5;
-  return display_helper (x, 0, "", STDERR, 1);
+  return display_helper (x, 0, "", g_stderr, 1);
 }
 
 SCM
@@ -245,6 +295,82 @@ exit_ (SCM x) ///((name . "exit"))
   exit (VALUE (x));
 }
 
+SCM
+frame_printer (SCM frame)
+{
+  fdputs ("#<", g_stdout); display_ (struct_ref_ (frame, 2));
+  fdputc (' ', g_stdout);
+  fdputs ("procedure: ", g_stdout); display_ (struct_ref_ (frame, 3));
+  fdputc ('>', g_stdout);
+}
+
+SCM
+make_frame_type () ///((internal))
+{
+  SCM record_type = cell_symbol_record_type; // FIXME
+  SCM fields = cell_nil;
+  fields = cons (cell_symbol_procedure, fields);
+  fields = cons (fields, cell_nil);
+  fields = cons (cell_symbol_frame, fields);
+  return make_struct (record_type, fields, cell_unspecified);
+}
+
+SCM
+make_frame (SCM stack, long index)
+{
+  SCM frame_type = make_frame_type ();
+  long array_index = (STACK_SIZE-(index*FRAME_SIZE));
+  SCM procedure = g_stack_array[array_index+FRAME_PROCEDURE];
+  if (!procedure)
+    procedure = cell_f;
+  SCM values = cell_nil;
+  values = cons (procedure, values);
+  values = cons (cell_symbol_frame, values);
+  return make_struct (frame_type, values, cell_frame_printer);
+}
+
+SCM
+make_stack_type () ///((internal))
+{
+  SCM record_type = cell_symbol_record_type; // FIXME
+  SCM fields = cell_nil;
+  fields = cons (cstring_to_symbol ("frames"), fields);
+  fields = cons (fields, cell_nil);
+  fields = cons (cell_symbol_stack, fields);
+  return make_struct (record_type, fields, cell_unspecified);
+}
+
+SCM
+make_stack (SCM stack) ///((arity . n))
+{
+  SCM stack_type = make_stack_type ();
+  long size = (STACK_SIZE-g_stack) / FRAME_SIZE;
+  SCM frames = make_vector__ (size);
+  for (long i=0; i<size; i++)
+    {
+      SCM frame = make_frame (stack, i);
+      vector_set_x_ (frames, i, frame);
+    }
+  SCM values = cell_nil;
+  values = cons (frames, values);
+  values = cons (cell_symbol_stack, values);
+  return make_struct (stack_type, values, cell_unspecified);
+}
+
+SCM
+stack_length (SCM stack)
+{
+  SCM frames = struct_ref_ (stack, 3);
+  return vector_length (frames);
+}
+
+SCM
+stack_ref (SCM stack, SCM index)
+{
+  SCM frames = struct_ref_ (stack, 3);
+  return vector_ref (frames, index);
+}
+
 SCM
 xassq (SCM x, SCM a) ///for speed in core only
 {
@@ -266,8 +392,9 @@ memq (SCM x, SCM a)
       }
     else if (t == TKEYWORD)
       {
-        SCM v = STRING (x);
-        while (a != cell_nil && v != STRING (CAR (a)))
+        while (a != cell_nil
+               && (TYPE (CAR (a)) != TKEYWORD
+                   || string_equal_p (x, CAR (a)) == cell_f))
           a = CDR (a);
       }
     else
@@ -293,11 +420,7 @@ equal2_p (SCM a, SCM b)
       return cell_f;
     }
   if (TYPE (a) == TSTRING && TYPE (b) == TSTRING)
-    {
-      a = STRING (a);
-      b = STRING (b);
-      goto equal2;
-    }
+    return string_equal_p (a, b);
   if (TYPE (a) == TVECTOR && TYPE (b) == TVECTOR)
     {
       if (LENGTH (a) != LENGTH (b))
@@ -325,3 +448,9 @@ last_pair (SCM x)
     x = CDR (x);
   return x;
 }
+
+SCM
+pair_p (SCM x)
+{
+  return TYPE (x) == TPAIR ? cell_t : cell_f;
+}
