@@ -18,10 +18,13 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <sys/stat.h>
-#include <sys/wait.h>
 #include <fcntl.h>
+#include <limits.h>
 #include <stdlib.h>
+#include <sys/stat.h>
+#include <sys/time.h>
+#include <sys/wait.h>
+#include <time.h>
 #include <unistd.h>
 
 int readchar ();
@@ -37,7 +40,12 @@ peekchar ()
       return c;
     }
   SCM port = current_input_port ();
-  return VALUE (CAR (STRING (port)));
+  SCM string = STRING (port);
+  size_t length = LENGTH (string);
+  if (!length)
+    return -1;
+  char const *p = CSTRING (string);
+  return p[0];
 }
 
 int
@@ -47,10 +55,12 @@ readchar ()
     return fdgetc (g_stdin);
   SCM port = current_input_port ();
   SCM string = STRING (port);
-  if (string == cell_nil)
+  size_t length = LENGTH (string);
+  if (!length)
     return -1;
-  int c = VALUE (CAR (string));
-  STRING (port) = CDR (string);
+  char const *p = CSTRING (string);
+  int c = *p++;
+  STRING (port) = make_string (p, length-1);
   return c;
 }
 
@@ -60,7 +70,14 @@ unreadchar (int c)
   if (g_stdin >= 0)
     return fdungetc (c, g_stdin);
   SCM port = current_input_port ();
-  STRING (port) = cons (MAKE_CHAR (c), STRING (port));
+  SCM string = STRING (port);
+  size_t length = LENGTH (string);
+  char *p = CSTRING (string);
+  p--;
+  string = make_string (p, length+1);
+  p = CSTRING (string);
+  p[0] = c;
+  STRING (port) = string;
   return c;
 }
 
@@ -90,9 +107,14 @@ peek_char ()
 }
 
 SCM
-read_char ()
+read_char (SCM port) ///((arity . n))
 {
-  return MAKE_CHAR (readchar ());
+  int fd = g_stdin;
+  if (TYPE (port) == TPAIR && TYPE (car (port)) == TNUMBER)
+    g_stdin = VALUE (CAR (port));
+  SCM c = MAKE_CHAR (readchar ());
+  g_stdin = fd;
+  return c;
 }
 
 SCM
@@ -109,19 +131,6 @@ write_char (SCM i) ///((arity . n))
   return i;
 }
 
-SCM
-read_string ()
-{
-  SCM lst = cell_nil;
-  SCM c = read_char ();
-  while (VALUE (c) != -1)
-    {
-      lst = append2 (lst, cons (c, cell_nil));
-      c = read_char ();
-    }
-  return MAKE_STRING (lst);
-}
-
 SCM
 write_byte (SCM x) ///((arity . n))
 {
@@ -130,6 +139,8 @@ write_byte (SCM x) ///((arity . n))
   int fd = g_stdout;
   if (TYPE (p) == TPAIR && TYPE (car (p)) == TNUMBER && VALUE (CAR (p)) != 1)
     fd = VALUE (CAR (p));
+  if (TYPE (p) == TPAIR && TYPE (car (p)) == TNUMBER && VALUE (CAR (p)) == 2)
+    fd = g_stderr;
   char cc = VALUE (c);
   write (fd, (char*)&cc, 1);
 #if !__MESC__
@@ -138,48 +149,27 @@ write_byte (SCM x) ///((arity . n))
   return c;
 }
 
-char string_to_cstring_buf[4096];
-char const*
-string_to_cstring_ (SCM s, char *buf)
-{
-  char *p = buf;
-  s = STRING(s);
-  while (s != cell_nil)
-    {
-      *p++ = VALUE (car (s));
-      s = cdr (s);
-    }
-  *p = 0;
-  return buf;
-}
-
-char const*
-string_to_cstring (SCM s)
-{
-  return string_to_cstring_ (s, string_to_cstring_buf);
-}
-
 SCM
 getenv_ (SCM s) ///((name . "getenv"))
 {
   char *p;
-  p = getenv (string_to_cstring (s));
-  return p ? MAKE_STRING (cstring_to_list (p)) : cell_f;
+  p = getenv (CSTRING (s));
+  return p ? MAKE_STRING0 (p) : cell_f;
 }
 
 SCM
 setenv_ (SCM s, SCM v) ///((name . "setenv"))
 {
   char buf[1024];
-  strcpy (buf, string_to_cstring (s));
-  setenv (buf, string_to_cstring (v), 1);
+  strcpy (buf, CSTRING (s));
+  setenv (buf, CSTRING (v), 1);
   return cell_unspecified;
 }
 
 SCM
 access_p (SCM file_name, SCM mode)
 {
-  return access (string_to_cstring (file_name), VALUE (mode)) == 0 ? cell_t : cell_f;
+  return access (CSTRING (file_name), VALUE (mode)) == 0 ? cell_t : cell_f;
 }
 
 SCM
@@ -188,6 +178,10 @@ current_input_port ()
   if (g_stdin >= 0)
     return MAKE_NUMBER (g_stdin);
   SCM x = g_ports;
+  if (g_debug > 2)
+    {
+      eputs ("ports:"); write_error_ (g_ports); eputs ("\n");
+    }
   while (x && PORT (CAR (x)) != g_stdin)
     x = CDR (x);
   return CAR (x);
@@ -196,13 +190,17 @@ current_input_port ()
 SCM
 open_input_file (SCM file_name)
 {
-  return MAKE_NUMBER (open (string_to_cstring (file_name), O_RDONLY));
+  return MAKE_NUMBER (open (CSTRING (file_name), O_RDONLY));
 }
 
 SCM
 open_input_string (SCM string)
 {
-  SCM port = MAKE_STRING_PORT (STRING (string));
+  SCM port = MAKE_STRING_PORT (string);
+  if (g_debug > 2)
+    {
+      eputs ("new port:"); write_error_ (port); eputs ("\n");
+    }
   g_ports = cons (port, g_ports);
   return port;
 }
@@ -224,6 +222,12 @@ current_output_port ()
   return MAKE_NUMBER (g_stdout);
 }
 
+SCM
+current_error_port ()
+{
+  return MAKE_NUMBER (g_stderr);
+}
+
 SCM
 open_output_file (SCM x) ///((arity . n))
 {
@@ -232,7 +236,7 @@ open_output_file (SCM x) ///((arity . n))
   int mode = S_IRUSR|S_IWUSR;
   if (TYPE (x) == TPAIR && TYPE (car (x)) == TNUMBER)
     mode = VALUE (car (x));
-  return MAKE_NUMBER (open (string_to_cstring (file_name), O_WRONLY|O_CREAT|O_TRUNC,mode));
+  return MAKE_NUMBER (open (CSTRING (file_name), O_WRONLY|O_CREAT|O_TRUNC,mode));
 }
 
 SCM
@@ -242,6 +246,13 @@ set_current_output_port (SCM port)
   return current_output_port ();
 }
 
+SCM
+set_current_error_port (SCM port)
+{
+  g_stderr = VALUE (port) ? VALUE (port) : STDERR;
+  return current_error_port ();
+}
+
 SCM
 force_output (SCM p) ///((arity . n))
 {
@@ -251,7 +262,7 @@ force_output (SCM p) ///((arity . n))
 SCM
 chmod_ (SCM file_name, SCM mode) ///((name . "chmod"))
 {
-  chmod (string_to_cstring (file_name), VALUE (mode));
+  chmod (CSTRING (file_name), VALUE (mode));
   return cell_unspecified;
 }
 
@@ -272,20 +283,17 @@ execl_ (SCM file_name, SCM args) ///((name . "execl"))
 {
   char *c_argv[1000];           // POSIX minimum 4096
   int i = 0;
-  int n = 0;
 
   if (length__ (args) > 1000)
     error (cell_symbol_system_error,
            cons (file_name,
-                 cons (MAKE_STRING (cstring_to_list ("too many arguments")),
+                 cons (MAKE_STRING0 ("too many arguments"),
                        cons (file_name, args))));
-  c_argv[i++] = (char*)string_to_cstring_ (file_name, string_to_cstring_buf+n);
-  n += length__ (STRING (file_name)) + 1;
+  c_argv[i++] = CSTRING (file_name);
   while (args != cell_nil)
     {
       assert (TYPE (CAR (args)) == TSTRING);
-      c_argv[i++] = (char*)string_to_cstring_ (CAR (args), string_to_cstring_buf+n);
-      n += length__ (STRING (CAR (args))) + 1;
+      c_argv[i++] = CSTRING (CAR (args));
       args = CDR (args);
       if (g_debug > 2)
         {
@@ -303,3 +311,77 @@ waitpid_ (SCM pid, SCM options)
   int child = waitpid (VALUE (pid), &status, VALUE (options));
   return cons (MAKE_NUMBER (child), MAKE_NUMBER (status));
 }
+
+#if __x86_64__
+/* Nanoseconds on 64-bit systems with POSIX timers.  */
+#define TIME_UNITS_PER_SECOND 1000000000
+#else
+/* Milliseconds for everyone else.  */
+#define TIME_UNITS_PER_SECOND 1000
+#endif
+
+struct timespec g_start_time;
+SCM
+init_time (SCM a) ///((internal))
+{
+  clock_gettime (CLOCK_PROCESS_CPUTIME_ID, &g_start_time);
+  a = acons (cell_symbol_internal_time_units_per_second, MAKE_NUMBER (TIME_UNITS_PER_SECOND), a);
+}
+
+SCM
+current_time ()
+{
+  return MAKE_NUMBER (time (0));
+}
+
+SCM
+gettimeofday_ () ///((name . "gettimeofday"))
+{
+  struct timeval time;
+  gettimeofday (&time, 0);
+  return cons (MAKE_NUMBER (time.tv_sec), MAKE_NUMBER (time.tv_usec));
+}
+
+long
+seconds_and_nanoseconds_to_long (long s, long ns)
+{
+  return s * TIME_UNITS_PER_SECOND
+    + ns / (1000000000 / TIME_UNITS_PER_SECOND);
+}
+
+SCM
+get_internal_run_time ()
+{
+  struct timespec ts;
+  clock_gettime (CLOCK_PROCESS_CPUTIME_ID, &ts);
+  long time = seconds_and_nanoseconds_to_long (ts.tv_sec - g_start_time.tv_sec,
+                                               ts.tv_nsec - g_start_time.tv_nsec);
+  return MAKE_NUMBER (time);
+}
+
+SCM
+getcwd_ () ///((name . "getcwd"))
+{
+  char buf[PATH_MAX];
+  return MAKE_STRING0 (getcwd (buf, PATH_MAX));
+}
+
+SCM
+dup_ (SCM port) ///((name . "dup"))
+{
+  return MAKE_NUMBER (dup (VALUE (port)));
+}
+
+SCM
+dup2_ (SCM old, SCM new) ///((name . "dup2"))
+{
+  dup2 (VALUE (old), VALUE (new));
+  return cell_unspecified;
+}
+
+SCM
+delete_file (SCM file_name)
+{
+  unlink (CSTRING (file_name));
+  return cell_unspecified;
+}
